@@ -8,13 +8,9 @@ use warnings;
 
 VolSurface::Utils - A class that handles several volatility related methods
 
-=head1 VERSION
-
-Version 1.00
-
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.03';
 
 use Carp;
 use List::MoreUtils qw(notall);
@@ -27,26 +23,34 @@ use base qw( Exporter );
 
 A class that handles several volatility related methods such as gets strikes from a certain delta point, gets delta from a certain vol point etc.
 
-use VolSurface::Utils;
-my $delta = get_delta_for_strike({
-            strike           => $strike,
-            atm_vol          => $atm_vol,
-            t                => $t,
-            spot             => $spot,
-            r_rate           => $r_rate,
-            q_rate           => $q_rate,
-            premium_adjusted => $premium_adjusted
-          });
+    use VolSurface::Utils;
+
+    my ($strike, $atm_vol, $t, $spot, $r_rate, $q_rate, $premium_adjusted) = (); ## initialize args
+    my $delta = get_delta_for_strike({
+        strike           => $strike,
+        atm_vol          => $atm_vol,
+        t                => $t,
+        spot             => $spot,
+        r_rate           => $r_rate,
+        q_rate           => $q_rate,
+        premium_adjusted => $premium_adjusted
+    });
 
 
 =head1 EXPORT
 
 get_delta_for_strike
+
 get_strike_for_spot_delta
+
 get_ATM_strike_for_spot_delta
+
 get_moneyness_for_strike
+
 get_strike_for_moneyness
+
 get_1vol_butterfly
+
 get_2vol_butterfly
 
 =cut
@@ -54,22 +58,21 @@ get_2vol_butterfly
 our @EXPORT_OK =
     qw( get_delta_for_strike get_strike_for_spot_delta get_ATM_strike_for_spot_delta get_moneyness_for_strike get_strike_for_moneyness get_1vol_butterfly get_2vol_butterfly);
 
-
 =head1 METHODS
 
 =head2 get_delta_for_strike
 
 Returns the delta (spot delta or premium adjusted spot delta) correspond to a particular strike with set of parameters such as atm volatility, time in year, spot level, rates
 
-my $delta = get_delta_for_strike({
-            strike           => $strike,
-            atm_vol          => $atm_vol,
-            t                => $t,
-            spot             => $spot,
-            r_rate           => $r_rate,
-            q_rate           => $q_rate,
-            premium_adjusted => $premium_adjusted
-});
+    my $delta = get_delta_for_strike({
+        strike           => $strike,
+        atm_vol          => $atm_vol,
+        t                => $t,
+        spot             => $spot,
+        r_rate           => $r_rate,
+        q_rate           => $q_rate,
+        premium_adjusted => $premium_adjusted
+    });
 
 Spot delta of an option is the percentage of the foreign notional one must buy when selling the option to hold a hedged position in the spot markets.
 
@@ -105,16 +108,16 @@ sub get_delta_for_strike {
 
 Returns the strike corresponds to a particular delta (spot delta or premium adjusted spot delta) with a set of parameters such as option type, atm vol, time in year, rates and spot level.
 
-my $strike = get_strike_for_spot_delta({
-            delta            => $delta,
-            option_type      => $option_type,
-            atm_vol          => $atm_vol,
-            t                => $t,
-            r_rate           => $r_rate,
-            q_rate           => $q_rate,
-            spot             => $spot,
-            premium_adjusted => $premium_adjusted
-        });
+    my $strike = get_strike_for_spot_delta({
+        delta            => $delta,
+        option_type      => $option_type,
+        atm_vol          => $atm_vol,
+        t                => $t,
+        r_rate           => $r_rate,
+        q_rate           => $q_rate,
+        spot             => $spot,
+        premium_adjusted => $premium_adjusted
+    });
 
 Calculation of strike depends on which type of delta we have. Delta provided must be on [0,1].
 
@@ -152,9 +155,9 @@ sub get_strike_for_spot_delta {
 sub _calculate_strike_for_vanilla_put {
     my $args = shift;
 
-    my ($normalInv, $delta, $option_type, $sigma, $time_in_years, $r, $d, $S, $premium_adjusted) = (
-        $args->{normalInv}, $args->{delta},  $args->{option_type}, $args->{atm_vol}, $args->{t},
-        $args->{r_rate},    $args->{q_rate}, $args->{spot},        $args->{premium_adjusted});
+    my ($normalInv, $delta, $sigma, $time_in_years, $r, $d, $S, $premium_adjusted) =
+        ($args->{normalInv}, $args->{delta}, $args->{atm_vol}, $args->{t},
+        $args->{r_rate}, $args->{q_rate}, $args->{spot}, $args->{premium_adjusted});
 
     #Step 1: Set initial k level with corresponding to spot delta without premium_adjusted
     my $k = $S * exp(($normalInv * $sigma * sqrt($time_in_years)) + ($r - $d + ($sigma * $sigma / 2)) * $time_in_years);
@@ -190,9 +193,9 @@ sub _calculate_strike_for_vanilla_put {
 sub _calculate_strike_for_vanilla_call {
     my $args = shift;
 
-    my ($normalInv, $delta, $option_type, $sigma, $time_in_years, $r, $d, $S, $premium_adjusted) = (
-        $args->{normalInv}, $args->{delta},  $args->{option_type}, $args->{atm_vol}, $args->{t},
-        $args->{r_rate},    $args->{q_rate}, $args->{spot},        $args->{premium_adjusted});
+    my ($normalInv, $delta, $sigma, $time_in_years, $r, $d, $S, $premium_adjusted) =
+        ($args->{normalInv}, $args->{delta}, $args->{atm_vol}, $args->{t},
+        $args->{r_rate}, $args->{q_rate}, $args->{spot}, $args->{premium_adjusted});
 
     #Step 1: Set initial k level with corresponding to spot delta without premium_adjusted.
     my $k = $S * exp(-($normalInv * $sigma * sqrt($time_in_years)) + ($r - $d + ($sigma * $sigma / 2)) * $time_in_years);
@@ -231,7 +234,7 @@ sub _calculate_strike_for_vanilla_call {
 
 Returns the ATM strike that satisifies straddle Delta neutral.
 
-my $atm_strike = get_ATM_strike_for_spot_delta({
+    my $atm_strike = get_ATM_strike_for_spot_delta({
         atm_vol => $atm_vol,
         t => $t,
         r_rate => $r_rate,
@@ -274,8 +277,7 @@ sub get_ATM_strike_for_spot_delta {
 
 Returns the corresponding moneyness point for a given strike.
 
-
-my $moneyness = get_moneyness_for_strike({
+    my $moneyness = get_moneyness_for_strike({
         strike => $strike,
         spot => $spot,
     });
@@ -297,7 +299,7 @@ sub get_moneyness_for_strike {
 Returns the corresponding strike value for a given moneyness point.
 
 
-my $strike = get_strike_for_moneyness({
+ my $strike = get_strike_for_moneyness({
         spot => $spot,
         moneyness => $moneyness
     });
@@ -321,7 +323,7 @@ sub get_strike_for_moneyness {
 
 Returns the two vol butterfly that satisfy the abitrage free constraint.
 
-my $bf = get_2vol_butterfly($spot, $tiy,$delta, $atm, $rr, $bf, $r, $d, $premium_adjusted, $bf_style);
+ my $bf = get_2vol_butterfly($spot, $tiy,$delta, $atm, $rr, $bf, $r, $d, $premium_adjusted, $bf_style);
 
 DESCRIPTION:
 There are two different butterfly vol:
@@ -397,17 +399,17 @@ sub get_2vol_butterfly {
 Returns the 1 vol butterfly which is the butterfly volatility that consistent with market standard conventions of trading the butterfly strategies (some paper called it market strnagle volatility)
 
     my $bf_1vol = get_1vol_butterfly({
-            spot             => $volsurface->underlying->spot,
-            tiy              => $tiy,
-            delta            => 0.25,
-            call_vol         => $smile->{25},
-            put_vol          => $smile->{75},
-            atm_vol          => $smile->{50},
-            bf_1vol          => 0,
-            r                => $volsurface->underlying->interest_rate_for($tiy),
-            q                => $volsurface->underlying->dividend_rate_for($tiy),
-            premium_adjusted => $volsurface->underlying->{market_convention}->{delta_premium_adjusted},
-            bf_style         => '2_vol',
+        spot             => $volsurface->underlying->spot,
+        tiy              => $tiy,
+        delta            => 0.25,
+        call_vol         => $smile->{25},
+        put_vol          => $smile->{75},
+        atm_vol          => $smile->{50},
+        bf_1vol          => 0,
+        r                => $volsurface->underlying->interest_rate_for($tiy),
+        q                => $volsurface->underlying->dividend_rate_for($tiy),
+        premium_adjusted => $volsurface->underlying->{market_convention}->{delta_premium_adjusted},
+        bf_style         => '2_vol',
     });
 
 =cut
@@ -547,9 +549,6 @@ sub _smile_approximation {
     my $d1_k1 = ((0.5 * $vol_k2 * $vol_k2 * $tiy) + log($F / $k1)) / ($vol_k2 * sqrt($tiy));
     my $d2_k1 = $d1_k1 - ($vol_k2 * sqrt($tiy));
 
-    my $d1_k2 = ((0.5 * $vol_k2 * $vol_k2 * $tiy) + log($F / $k2)) / ($vol_k2 * sqrt($tiy));
-    my $d2_k2 = $d1_k2 - ($vol_k2 * sqrt($tiy));
-
     my $d1_k3 = ((0.5 * $vol_k2 * $vol_k2 * $tiy) + log($F / $k3)) / ($vol_k2 * sqrt($tiy));
     my $d2_k3 = $d1_k3 - ($vol_k2 * sqrt($tiy));
 
@@ -610,7 +609,6 @@ sub _implied_vol {
     return $vol;
 }
 
-
 =head1 AUTHOR
 
 Binary.com, C<< <support at binary.com> >>
@@ -663,4 +661,4 @@ Copyright 2015 Binary.com.
 
 =cut
 
-1; # End of VolSurface::Utils
+1;    # End of VolSurface::Utils
